@@ -12,7 +12,7 @@ from typing import Dict, List, Optional, Tuple, Any
 from dataclasses import dataclass
 from enum import Enum
 
-from ..cache import (
+from ..analysis import (
     CacheDiscoveryService,
     SessionCacheParser,
     UsagePatternAnalyzer,
